pygeodesy.nvectorBase.LatLonNvectorBase

Package pygeodesy :: Module nvectorBase :: Class LatLonNvectorBase |
[frames] | no frames]

# Class LatLonNvectorBase

           object --+
                    |
         named._Named --+
                        |
         named._NamedBase --+
                            |
           object --+       |
                    |       |
         named._Named --+   |
                        |   |
    ecefLocals._EcefLocal --+
                            |
        latlonBase.LatLonBase --+
                                |
                               LatLonNvectorBase

Known Subclasses:
  - ellipsoidalNvector.LatLon
  - , sphericalNvector.LatLon

(INTERNAL) Base class for n-vector-based ellipsoidal and spherical `LatLon`s.

Instance Methods
intersections2(self, radius1, other, radius2, **kwds) Not implemented, throws a `NotImplementedError` always. |
others(self, *other, **name_other_up) Refined class comparison. |
toNvector(self, **Nvector_and_kwds) Convert this point to `Nvector` components, including height. |
triangulate(self, bearing1, other, bearing2, height=None, wrap=False) Locate a point given this, an other point and the (initial) bearing from this and the other point. |
trilaterate(self, distance1, point2, distance2, point3, distance3, radius=6371008.771415, height=None, useZ=False, wrap=False) Locate a point at given distances from this and two other points. |
trilaterate5(self, distance1, point2, distance2, point3, distance3, area=False, eps=0.9999999999999998, radius=6371008.771415, wrap=False) Not implemented for `area=True` and falls back to method `trilaterate`. |
Inherited from `latlonBase.LatLonBase`: `PointsIter`, `__eq__`, `__init__`, `__ne__`, `__str__`, `antipode`, `bounds`, `boundsOf`, `chordTo`, `circin6`, `circum3`, `circum4_`, `compassAngle`, `compassAngleTo`, `cosineAndoyerLambertTo`, `cosineForsytheAndoyerLambertTo`, `cosineLawTo`, `destinationXyz`, `equals`, `equals3`, `equirectangularTo`, `euclideanTo`, `flatLocalTo`, `flatPolarTo`, `hartzell`, `haversineTo`, `height4`, `heightStr`, `hubenyTo`, `intersecant2`, `isantipode`, `isantipodeTo`, `isequalTo`, `isequalTo3`, `latlon2`, `latlon2round`, `latlon_`, `nearestOn6`, `nearestTo`, `normal`, `philam2`, `points`, `points2`, `radii11`, `rhumbAzimuthTo`, `rhumbDestination`, `rhumbDistanceTo`, `rhumbIntersecant2`, `rhumbLine`, `rhumbMidpointTo`, `thomasTo`, `to2ab`, `to3llh`, `to3xyz`, `toCartesian`, `toDatum`, `toEcef`, `toNormal`, `toStr`, `toVector`, `toVector3d`, `toWm`, `vincentysTo` Inherited from `named._NamedBase`: `__repr__`, `toRepr` Inherited from `ecefLocals._EcefLocal`: `toAer`, `toEnu`, `toLocal`, `toLtp`, `toNed`, `toXyz` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `latlonBase.LatLonBase`: `clipid`, `datum`, `ellipsoidalLatLon`, `height`, `isEllipsoidal`, `isSpherical`, `isnormal`, `lam`, `lat`, `latlon`, `latlonheight`, `lon`, `phi`, `philam`, `philamheight`, `sphericalLatLon`, `xyz`, `xyz3`, `xyzh` Inherited from `ecefLocals._EcefLocal`: `Ecef` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### others (self, *other, **name_other_up) |
Refined class comparison. Arguments: `other` - The other instance (`LatLonNvectorBase`). `name_other_up` - Overriding `name=other` and `up=1` keyword arguments. Returns: The `other` if compatible. Raises: `TypeError` - Incompatible `other` `type`. Overrides: named._NamedBase.others

### toNvector (self, **Nvector_and_kwds) |
Convert this point to `Nvector` components, including height. Arguments: `Nvector_and_kwds` - Optional `Nvector` class and `Nvector` keyword arguments, Specify `Nvector=...` to override this `Nvector` class or use `Nvector=None`. Returns: An `Nvector` or if `Nvector is None`, a Vector4Tuple`(x, y, z, h)`. Raises: `TypeError` - Invalid `Nvector` or other `Nvector_and_kwds` item. Overrides: latlonBase.LatLonBase.toNvector

### triangulate (self, bearing1, other, bearing2, height=None, wrap=False) |
Locate a point given this, an other point and the (initial) bearing from this and the other point. Arguments: `bearing1` - Bearing at this point (compass `degrees360`). `other` - The other point (`LatLon`). `bearing2` - Bearing at the other point (compass `degrees360`). `height` - Optional height at the triangulated point, overriding the mean height (`meter`). `wrap` - If `True`, use this and the `other` point normalized (`bool`). Returns: Triangulated point (`LatLon`). Raises: `TypeError` - Invalid `other` point. `Valuerror` - Points coincide.

### trilaterate (self, distance1, point2, distance2, point3, distance3, radius=6371008.771415, height=None, useZ=False, wrap=False) |
Locate a point at given distances from this and two other points. Arguments: `distance1` - Distance to this point (`meter`, same units as `radius`). `point2` - Second reference point (`LatLon`). `distance2` - Distance to point2 (`meter`, same units as `radius`). `point3` - Third reference point (`LatLon`). `distance3` - Distance to point3 (`meter`, same units as `radius`). `radius` - Mean earth radius (`meter`). `height` - Optional height at trilaterated point, overriding the mean height (`meter`, same units as `radius`). `useZ` - Include Z component iff non-NaN, non-zero (`bool`). `wrap` - If `True`, use this, `point2` and `point3` normalized (`bool`). Returns: Trilaterated point (`LatLon`). Raises: `IntersectionError` - No intersection, trilateration failed. `TypeError` - Invalid `point2` or `point3`. `ValueError` - Some `points` coincide or invalid `distance1`, `distance2`, `distance3` or `radius`. See Also: Trilateration, Veness' JavaScript Trilateration and method `LatLon.trilaterate5` of other, non-`Nvector LatLon` classes.

### trilaterate5 (self, distance1, point2, distance2, point3, distance3, area=False, eps=0.9999999999999998, radius=6371008.771415, wrap=False) |
Not implemented for `area=True` and falls back to method `trilaterate`. Returns: A Trilaterate5Tuple`(min, minPoint, max, maxPoint, n)` with a single trilaterated intersection `minPoint is maxPoint`, `min is max` the nearest intersection margin and count `n = 1`. Raises: `NotImplementedError` - Keyword argument `area=True` not (yet) supported. See Also: Method trilaterate for other and more details.